/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */


#ifndef INCLUDED_SALHELPER_CONDITION_HXX
#define INCLUDED_SALHELPER_CONDITION_HXX


#include "osl/conditn.hxx"
#include "salhelper/salhelperdllapi.h"

namespace osl { class Mutex; }

namespace salhelper
{

    class SALHELPER_DLLPUBLIC Condition
    {
        friend class ConditionModifier;
        friend class ConditionWaiter;

    public:

        Condition(osl::Mutex& aMutex);

        virtual ~Condition();


    protected:

        virtual bool applies() const = 0;


    private:
        Condition(Condition &) SAL_DELETED_FUNCTION;
        void operator =(Condition &) SAL_DELETED_FUNCTION;

        osl::Mutex&     m_aMutex;
        osl::Condition  m_aCondition;
    };


    class SALHELPER_DLLPUBLIC ConditionModifier
    {
    public:

        ConditionModifier(Condition& aCond);

        ~ConditionModifier();


    private:
        ConditionModifier(ConditionModifier &) SAL_DELETED_FUNCTION;
        void operator =(ConditionModifier &) SAL_DELETED_FUNCTION;

        Condition& m_aCond;
    };


    class SALHELPER_DLLPUBLIC ConditionWaiter
    {
    public:

        ConditionWaiter(Condition& aCond);

        struct SALHELPER_DLLPUBLIC timedout {
            timedout();

            timedout(timedout const &);

            virtual ~timedout();

            timedout & operator =(timedout const &);
        };

        /// @throws timedout
        ConditionWaiter(Condition& aCond,sal_uInt32 milliSec);


        ~ConditionWaiter();


    private:
        ConditionWaiter(ConditionWaiter &) SAL_DELETED_FUNCTION;
        void operator =(ConditionWaiter &) SAL_DELETED_FUNCTION;

        Condition& m_aCond;
    };


}   // namespace salhelper


#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
